Console Port Template - Nautobot Documentation

Skip to content

# Console Port Templates

A template for a console port that will be created on all instantiations of the parent device type. Each console port can be assigned a physical type.

Added in version 1.4.5

The fields `created` and `last_updated` were added to all device component template models. If you upgraded from Nautobot 1.4.4 or earlier, the values for these fields will default to `None` (null).